## ecr.commands.cmd_exit

src/ecr/commands/cmd_exit.py
    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    from ..ui.command import Command, Namespace, ReturnCode

    class ExitCommand(Command):
        @staticmethod
        def default(args: Namespace)->ReturnCode:  # pylint: disable=W0613
            return ReturnCode.EXIT

        def __init__(self):
            super().__init__("exit", help="Exit", func=ExitCommand.default)